{
  am_pm_abbreviated => [
    "AM",
    "PM",
  ],
  available_formats => {
    Bh => "h B",
    Bhm => "h:mm B",
    Bhms => "h:mm:ss B",
    E => "ccc",
    EBhm => "E h:mm B",
    EBhms => "E h:mm:ss B",
    EHm => "E HH:mm",
    EHms => "E HH:mm:ss",
    Ed => "d E",
    Ehm => "E h:mm a",
    Ehms => "E h:mm:ss a",
    Gy => "y G",
    GyMMM => "MMM y G",
    GyMMMEd => "E d MMM y G",
    GyMMMd => "d MMM y G",
    GyMd => "GGGGG y-MM-dd",
    H => "HH",
    Hm => "HH:mm",
    Hms => "HH:mm:ss",
    Hmsv => "HH:mm:ss v",
    Hmv => "HH:mm v",
    M => "L",
    MEd => "E d/M",
    MMM => "LLL",
    MMMEd => "E d MMM",
    "MMMMW-count-other" => "\N{U+179f}\N{U+1794}\N{U+17d2}\N{U+178f}\N{U+17b6}\N{U+17a0}\N{U+17cd}\N{U+1791}\N{U+17b8} W \N{U+1793}\N{U+17c3}\N{U+1781}\N{U+17c2} MMMM",
    MMMMd => "d MMMM",
    MMMd => "d MMM",
    Md => "d/M",
    d => "d",
    h => "h\N{U+202f}a",
    hm => "h:mm a",
    hms => "h:mm:ss a",
    hmsv => "h:mm:ss a v",
    hmv => "h:mm a v",
    ms => "mm:ss",
    y => "y",
    yM => "M/y",
    yMEd => "E d/M/y",
    yMMM => "MMM y",
    yMMMEd => "E d MMM y",
    yMMMM => "MMMM y",
    yMMMd => "d MMM y",
    yMd => "d/M/y",
    yQQQ => "QQQ y",
    yQQQQ => "QQQQ y",
    "yw-count-other" => "\N{U+179f}\N{U+1794}\N{U+17d2}\N{U+178f}\N{U+17b6}\N{U+17a0}\N{U+17cd}\N{U+1791}\N{U+17b8} w \N{U+1793}\N{U+17c3}\N{U+1786}\N{U+17d2}\N{U+1793}\N{U+17b6}\N{U+17c6} Y",
  },
  code => "km-KH",
  date_format_full => "EEEE d MMMM y",
  date_format_long => "d MMMM y",
  date_format_medium => "d MMM y",
  date_format_short => "d/M/yy",
  datetime_format_full => "{1}, {0}",
  datetime_format_long => "{1}, {0}",
  datetime_format_medium => "{1}, {0}",
  datetime_format_short => "{1}, {0}",
  day_format_abbreviated => [
    "\N{U+1785}\N{U+1793}\N{U+17d2}\N{U+1791}",
    "\N{U+17a2}\N{U+1784}\N{U+17d2}\N{U+1782}\N{U+17b6}\N{U+179a}",
    "\N{U+1796}\N{U+17bb}\N{U+1792}",
    "\N{U+1796}\N{U+17d2}\N{U+179a}\N{U+17a0}",
    "\N{U+179f}\N{U+17bb}\N{U+1780}\N{U+17d2}\N{U+179a}",
    "\N{U+179f}\N{U+17c5}\N{U+179a}\N{U+17cd}",
    "\N{U+17a2}\N{U+17b6}\N{U+1791}\N{U+17b7}\N{U+178f}\N{U+17d2}\N{U+1799}",
  ],
  day_format_narrow => [
    "\N{U+1785}",
    "\N{U+17a2}",
    "\N{U+1796}",
    "\N{U+1796}",
    "\N{U+179f}",
    "\N{U+179f}",
    "\N{U+17a2}",
  ],
  day_format_wide => [
    "\N{U+1785}\N{U+17d0}\N{U+1793}\N{U+17d2}\N{U+1791}",
    "\N{U+17a2}\N{U+1784}\N{U+17d2}\N{U+1782}\N{U+17b6}\N{U+179a}",
    "\N{U+1796}\N{U+17bb}\N{U+1792}",
    "\N{U+1796}\N{U+17d2}\N{U+179a}\N{U+17a0}\N{U+179f}\N{U+17d2}\N{U+1794}\N{U+178f}\N{U+17b7}\N{U+17cd}",
    "\N{U+179f}\N{U+17bb}\N{U+1780}\N{U+17d2}\N{U+179a}",
    "\N{U+179f}\N{U+17c5}\N{U+179a}\N{U+17cd}",
    "\N{U+17a2}\N{U+17b6}\N{U+1791}\N{U+17b7}\N{U+178f}\N{U+17d2}\N{U+1799}",
  ],
  day_stand_alone_abbreviated => [
    "\N{U+1785}\N{U+1793}\N{U+17d2}\N{U+1791}",
    "\N{U+17a2}\N{U+1784}\N{U+17d2}\N{U+1782}\N{U+17b6}\N{U+179a}",
    "\N{U+1796}\N{U+17bb}\N{U+1792}",
    "\N{U+1796}\N{U+17d2}\N{U+179a}\N{U+17a0}",
    "\N{U+179f}\N{U+17bb}\N{U+1780}\N{U+17d2}\N{U+179a}",
    "\N{U+179f}\N{U+17c5}\N{U+179a}\N{U+17cd}",
    "\N{U+17a2}\N{U+17b6}\N{U+1791}\N{U+17b7}\N{U+178f}\N{U+17d2}\N{U+1799}",
  ],
  day_stand_alone_narrow => [
    "\N{U+1785}",
    "\N{U+17a2}",
    "\N{U+1796}",
    "\N{U+1796}",
    "\N{U+179f}",
    "\N{U+179f}",
    "\N{U+17a2}",
  ],
  day_stand_alone_wide => [
    "\N{U+1785}\N{U+1793}\N{U+17d2}\N{U+1791}",
    "\N{U+17a2}\N{U+1784}\N{U+17d2}\N{U+1782}\N{U+17b6}\N{U+179a}",
    "\N{U+1796}\N{U+17bb}\N{U+1792}",
    "\N{U+1796}\N{U+17d2}\N{U+179a}\N{U+17a0}\N{U+179f}\N{U+17d2}\N{U+1794}\N{U+178f}\N{U+17b7}\N{U+17cd}",
    "\N{U+179f}\N{U+17bb}\N{U+1780}\N{U+17d2}\N{U+179a}",
    "\N{U+179f}\N{U+17c5}\N{U+179a}\N{U+17cd}",
    "\N{U+17a2}\N{U+17b6}\N{U+1791}\N{U+17b7}\N{U+178f}\N{U+17d2}\N{U+1799}",
  ],
  era_abbreviated => [
    "\N{U+1798}\N{U+17bb}\N{U+1793} \N{U+1782}.\N{U+179f}.",
    "\N{U+1782}.\N{U+179f}.",
  ],
  era_narrow => [
    "\N{U+1798}\N{U+17bb}\N{U+1793} \N{U+1782}.\N{U+179f}.",
    "\N{U+1782}.\N{U+179f}.",
  ],
  era_wide => [
    "\N{U+1798}\N{U+17bb}\N{U+1793}\N{U+200b}\N{U+1782}\N{U+17d2}\N{U+179a}\N{U+17b7}\N{U+179f}\N{U+17d2}\N{U+178f}\N{U+179f}\N{U+1780}\N{U+179a}\N{U+17b6}\N{U+1787}",
    "\N{U+1782}\N{U+17d2}\N{U+179a}\N{U+17b7}\N{U+179f}\N{U+17d2}\N{U+178f}\N{U+179f}\N{U+1780}\N{U+179a}\N{U+17b6}\N{U+1787}",
  ],
  first_day_of_week => 7,
  glibc_date_1_format => "%A \N{U+1790}\N{U+17d2}\N{U+1784}\N{U+17c3} %e \N{U+1781}\N{U+17c2} %B \N{U+1786}\N{U+17d2}\N{U+1793}\N{U+17b6}\N{U+17c6} %Y, %H \N{U+1798}\N{U+17c9}\N{U+17c4}\N{U+1784} %M \N{U+1793}\N{U+17b6}\N{U+1791}\N{U+17b8} %S \N{U+179c}\N{U+17b7}\N{U+1793}\N{U+17b6}\N{U+1791}\N{U+17b8}\N{U+200b}",
  glibc_date_format => "%e %B %Y",
  glibc_datetime_format => "%A \N{U+1790}\N{U+17d2}\N{U+1784}\N{U+17c3} %e \N{U+1781}\N{U+17c2} %B \N{U+1786}\N{U+17d2}\N{U+1793}\N{U+17b6}\N{U+17c6} %Y, %H \N{U+1798}\N{U+17c9}\N{U+17c4}\N{U+1784} %M \N{U+1793}\N{U+17b6}\N{U+1791}\N{U+17b8} %S \N{U+179c}\N{U+17b7}\N{U+1793}\N{U+17b6}\N{U+1791}\N{U+17b8}\N{U+200b}",
  glibc_time_12_format => "%I:%M:%S %p",
  glibc_time_format => "%H:%M:%S",
  language => "Khmer",
  month_format_abbreviated => [
    "\N{U+1798}\N{U+1780}\N{U+179a}\N{U+17b6}",
    "\N{U+1780}\N{U+17bb}\N{U+1798}\N{U+17d2}\N{U+1797}\N{U+17c8}",
    "\N{U+1798}\N{U+17b8}\N{U+1793}\N{U+17b6}",
    "\N{U+1798}\N{U+17c1}\N{U+179f}\N{U+17b6}",
    "\N{U+17a7}\N{U+179f}\N{U+1797}\N{U+17b6}",
    "\N{U+1798}\N{U+17b7}\N{U+1790}\N{U+17bb}\N{U+1793}\N{U+17b6}",
    "\N{U+1780}\N{U+1780}\N{U+17d2}\N{U+1780}\N{U+178a}\N{U+17b6}",
    "\N{U+179f}\N{U+17b8}\N{U+17a0}\N{U+17b6}",
    "\N{U+1780}\N{U+1789}\N{U+17d2}\N{U+1789}\N{U+17b6}",
    "\N{U+178f}\N{U+17bb}\N{U+179b}\N{U+17b6}",
    "\N{U+179c}\N{U+17b7}\N{U+1785}\N{U+17d2}\N{U+1786}\N{U+17b7}\N{U+1780}\N{U+17b6}",
    "\N{U+1792}\N{U+17d2}\N{U+1793}\N{U+17bc}",
  ],
  month_format_narrow => [
    "\N{U+1798}",
    "\N{U+1780}",
    "\N{U+1798}",
    "\N{U+1798}",
    "\N{U+17a7}",
    "\N{U+1798}",
    "\N{U+1780}",
    "\N{U+179f}",
    "\N{U+1780}",
    "\N{U+178f}",
    "\N{U+179c}",
    "\N{U+1792}",
  ],
  month_format_wide => [
    "\N{U+1798}\N{U+1780}\N{U+179a}\N{U+17b6}",
    "\N{U+1780}\N{U+17bb}\N{U+1798}\N{U+17d2}\N{U+1797}\N{U+17c8}",
    "\N{U+1798}\N{U+17b8}\N{U+1793}\N{U+17b6}",
    "\N{U+1798}\N{U+17c1}\N{U+179f}\N{U+17b6}",
    "\N{U+17a7}\N{U+179f}\N{U+1797}\N{U+17b6}",
    "\N{U+1798}\N{U+17b7}\N{U+1790}\N{U+17bb}\N{U+1793}\N{U+17b6}",
    "\N{U+1780}\N{U+1780}\N{U+17d2}\N{U+1780}\N{U+178a}\N{U+17b6}",
    "\N{U+179f}\N{U+17b8}\N{U+17a0}\N{U+17b6}",
    "\N{U+1780}\N{U+1789}\N{U+17d2}\N{U+1789}\N{U+17b6}",
    "\N{U+178f}\N{U+17bb}\N{U+179b}\N{U+17b6}",
    "\N{U+179c}\N{U+17b7}\N{U+1785}\N{U+17d2}\N{U+1786}\N{U+17b7}\N{U+1780}\N{U+17b6}",
    "\N{U+1792}\N{U+17d2}\N{U+1793}\N{U+17bc}",
  ],
  month_stand_alone_abbreviated => [
    "\N{U+1798}\N{U+1780}\N{U+179a}\N{U+17b6}",
    "\N{U+1780}\N{U+17bb}\N{U+1798}\N{U+17d2}\N{U+1797}\N{U+17c8}",
    "\N{U+1798}\N{U+17b8}\N{U+1793}\N{U+17b6}",
    "\N{U+1798}\N{U+17c1}\N{U+179f}\N{U+17b6}",
    "\N{U+17a7}\N{U+179f}\N{U+1797}\N{U+17b6}",
    "\N{U+1798}\N{U+17b7}\N{U+1790}\N{U+17bb}\N{U+1793}\N{U+17b6}",
    "\N{U+1780}\N{U+1780}\N{U+17d2}\N{U+1780}\N{U+178a}\N{U+17b6}",
    "\N{U+179f}\N{U+17b8}\N{U+17a0}\N{U+17b6}",
    "\N{U+1780}\N{U+1789}\N{U+17d2}\N{U+1789}\N{U+17b6}",
    "\N{U+178f}\N{U+17bb}\N{U+179b}\N{U+17b6}",
    "\N{U+179c}\N{U+17b7}\N{U+1785}\N{U+17d2}\N{U+1786}\N{U+17b7}\N{U+1780}\N{U+17b6}",
    "\N{U+1792}\N{U+17d2}\N{U+1793}\N{U+17bc}",
  ],
  month_stand_alone_narrow => [
    "\N{U+1798}",
    "\N{U+1780}",
    "\N{U+1798}",
    "\N{U+1798}",
    "\N{U+17a7}",
    "\N{U+1798}",
    "\N{U+1780}",
    "\N{U+179f}",
    "\N{U+1780}",
    "\N{U+178f}",
    "\N{U+179c}",
    "\N{U+1792}",
  ],
  month_stand_alone_wide => [
    "\N{U+1798}\N{U+1780}\N{U+179a}\N{U+17b6}",
    "\N{U+1780}\N{U+17bb}\N{U+1798}\N{U+17d2}\N{U+1797}\N{U+17c8}",
    "\N{U+1798}\N{U+17b8}\N{U+1793}\N{U+17b6}",
    "\N{U+1798}\N{U+17c1}\N{U+179f}\N{U+17b6}",
    "\N{U+17a7}\N{U+179f}\N{U+1797}\N{U+17b6}",
    "\N{U+1798}\N{U+17b7}\N{U+1790}\N{U+17bb}\N{U+1793}\N{U+17b6}",
    "\N{U+1780}\N{U+1780}\N{U+17d2}\N{U+1780}\N{U+178a}\N{U+17b6}",
    "\N{U+179f}\N{U+17b8}\N{U+17a0}\N{U+17b6}",
    "\N{U+1780}\N{U+1789}\N{U+17d2}\N{U+1789}\N{U+17b6}",
    "\N{U+178f}\N{U+17bb}\N{U+179b}\N{U+17b6}",
    "\N{U+179c}\N{U+17b7}\N{U+1785}\N{U+17d2}\N{U+1786}\N{U+17b7}\N{U+1780}\N{U+17b6}",
    "\N{U+1792}\N{U+17d2}\N{U+1793}\N{U+17bc}",
  ],
  name => "Khmer Cambodia",
  native_language => "\N{U+1781}\N{U+17d2}\N{U+1798}\N{U+17c2}\N{U+179a}",
  native_name => "\N{U+1781}\N{U+17d2}\N{U+1798}\N{U+17c2}\N{U+179a} \N{U+1780}\N{U+1798}\N{U+17d2}\N{U+1796}\N{U+17bb}\N{U+1787}\N{U+17b6}",
  native_script => undef,
  native_territory => "\N{U+1780}\N{U+1798}\N{U+17d2}\N{U+1796}\N{U+17bb}\N{U+1787}\N{U+17b6}",
  native_variant => undef,
  quarter_format_abbreviated => [
    "\N{U+178f}\N{U+17d2}\N{U+179a}\N{U+17b8}\N{U+1798}\N{U+17b6}\N{U+179f}\N{U+1791}\N{U+17b8} 1",
    "\N{U+178f}\N{U+17d2}\N{U+179a}\N{U+17b8}\N{U+1798}\N{U+17b6}\N{U+179f}\N{U+1791}\N{U+17b8} 2",
    "\N{U+178f}\N{U+17d2}\N{U+179a}\N{U+17b8}\N{U+1798}\N{U+17b6}\N{U+179f}\N{U+1791}\N{U+17b8} 3",
    "\N{U+178f}\N{U+17d2}\N{U+179a}\N{U+17b8}\N{U+1798}\N{U+17b6}\N{U+179f}\N{U+1791}\N{U+17b8} 4",
  ],
  quarter_format_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_format_wide => [
    "\N{U+178f}\N{U+17d2}\N{U+179a}\N{U+17b8}\N{U+1798}\N{U+17b6}\N{U+179f}\N{U+1791}\N{U+17b8} 1",
    "\N{U+178f}\N{U+17d2}\N{U+179a}\N{U+17b8}\N{U+1798}\N{U+17b6}\N{U+179f}\N{U+1791}\N{U+17b8} 2",
    "\N{U+178f}\N{U+17d2}\N{U+179a}\N{U+17b8}\N{U+1798}\N{U+17b6}\N{U+179f}\N{U+1791}\N{U+17b8} 3",
    "\N{U+178f}\N{U+17d2}\N{U+179a}\N{U+17b8}\N{U+1798}\N{U+17b6}\N{U+179f}\N{U+1791}\N{U+17b8} 4",
  ],
  quarter_stand_alone_abbreviated => [
    "\N{U+178f}\N{U+17d2}\N{U+179a}\N{U+17b8}\N{U+1798}\N{U+17b6}\N{U+179f}\N{U+1791}\N{U+17b8} 1",
    "\N{U+178f}\N{U+17d2}\N{U+179a}\N{U+17b8}\N{U+1798}\N{U+17b6}\N{U+179f}\N{U+1791}\N{U+17b8} 2",
    "\N{U+178f}\N{U+17d2}\N{U+179a}\N{U+17b8}\N{U+1798}\N{U+17b6}\N{U+179f}\N{U+1791}\N{U+17b8} 3",
    "\N{U+178f}\N{U+17d2}\N{U+179a}\N{U+17b8}\N{U+1798}\N{U+17b6}\N{U+179f}\N{U+1791}\N{U+17b8} 4",
  ],
  quarter_stand_alone_narrow => [
    1,
    2,
    3,
    4,
  ],
  quarter_stand_alone_wide => [
    "\N{U+178f}\N{U+17d2}\N{U+179a}\N{U+17b8}\N{U+1798}\N{U+17b6}\N{U+179f}\N{U+1791}\N{U+17b8} 1",
    "\N{U+178f}\N{U+17d2}\N{U+179a}\N{U+17b8}\N{U+1798}\N{U+17b6}\N{U+179f}\N{U+1791}\N{U+17b8} 2",
    "\N{U+178f}\N{U+17d2}\N{U+179a}\N{U+17b8}\N{U+1798}\N{U+17b6}\N{U+179f}\N{U+1791}\N{U+17b8} 3",
    "\N{U+178f}\N{U+17d2}\N{U+179a}\N{U+17b8}\N{U+1798}\N{U+17b6}\N{U+179f}\N{U+1791}\N{U+17b8} 4",
  ],
  script => undef,
  territory => "Cambodia",
  time_format_full => "h:mm:ss a zzzz",
  time_format_long => "h:mm:ss a z",
  time_format_medium => "h:mm:ss a",
  time_format_short => "h:mm a",
  variant => undef,
  version => 46,
}
